TrackerTrainingCallback
=======================

.. currentmodule:: pykeen.training.callbacks

.. autoclass:: TrackerTrainingCallback
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TrackerTrainingCallback.post_epoch

   .. rubric:: Methods Documentation

   .. automethod:: post_epoch
